@@ -1,19 +1,21 @@
-import argparse
-import ast
-import cPickle
-import logging
-import os
-import random
-import re
-import sys
 
-from Bio import AlignIO
-from Bio import SeqIO
-from Bio.Align.Applications import ClustalwCommandline
+import ast
 from ete2 import Tree
 
-import mitos.mitofile as mitofile
-from mitos.sequence import sequence
+from __future__ import print_function
+import os
+import argparse
+import cPickle
+import logging
+import random
+import sys
+import re
+from Bio import SeqIO
+from Bio.Align.Applications import ClustalwCommandline
+from Bio import AlignIO
+
+import mitofile as mitofile
+from sequence import sequence
 
 
 ####
@@ -22,7 +24,7 @@ from mitos.sequence import sequence
 
 # ##
 # Office:
-# ---------
+#---------
 taxidmap_file = "/homes/brauerei/abdullah/Desktop/PhD/python/mtdbnew/src/RNAremold/tRNA-phylo/004/tRNA-CM/RefSeq/new_taxidtoacc-refseq63.txt"
 
 # tree_file = sys.argv[2]
@@ -38,7 +40,7 @@ outp_dir = "/homes/brauerei/abdullah/Desktop/PhD/python/mtdbnew/src/RNAremold/tR
 
 
 # MAC
-# -------
+#-------
 
 # taxidmap_file = "/Users/Abdullah/Documents/PhD/work/Others/mtdb/src/RNAremold/tRNA-phylo/004/tRNA-CM/taxidtoacc-refseq58.txt"
 
@@ -96,7 +98,7 @@ outp_dir = "/homes/brauerei/abdullah/Desktop/PhD/python/mtdbnew/src/RNAremold/tR
 #
 #             if chld.is_leaf():
 #
-#                 if found_gene(chld.name, "nad5", data_gene) is True:
+#                 if found_gene(chld.name, "nad5", data_gene) == True:
 #                     fasta+=chld.seq
 #                 else:
 #                     print(nd.name + " does not have nad5 gene")
@@ -163,7 +165,7 @@ outp_dir = "/homes/brauerei/abdullah/Desktop/PhD/python/mtdbnew/src/RNAremold/tR
 #                 #print "!!! WTF", chld.name
 #                 if chld.is_leaf():
 #
-#                     if found_gene(chld.name, "nad5", data_gene) is True:
+#                     if found_gene(chld.name, "nad5", data_gene) == True:
 #                         fasta+=chld.seq
 #                     else:
 #                         print nd.name + " does not have nad5 gene"
@@ -262,7 +264,7 @@ def load_data(dirs):
         # if dr.split("/")[-1] == "NC_023272":
         #    print dr
         # if not os.listdir(dr) == []:
-        #    continue
+            # continue
 
         if not os.path.isdir(dr):
             sys.stderr.write("skipping non dir %s\n" % dr)
@@ -278,17 +280,17 @@ def load_data(dirs):
             f = open(dr + "/result.pkl")
             features = cPickle.load(f)
             f.close()
-        except Exception:
+        except IOErrgene == row[i].name:
             sys.stderr.write("skipping (no features) %s\n" % dr)
             continue
 
         tmp = [x for x in features if (
-            x.type == "tRNA" and x.anticodon is None)]
+            x.type == "tRNA" and x.anticodon == None)]
         for t in tmp:
             logging.warning("remove degenerated tRNA: %s %s" %
                             (gb.accession, t.name))
 
-        # data_trna[ gb.accession ] = [ x for x in features if ( x.type == "tRNA" and x.anticodon is not None )]
+        # data_trna[ gb.accession ] = [ x for x in features if ( x.type == "tRNA" and x.anticodon != None )]
         data_trna[gb.accession] = [x for x in features if (x.type == "tRNA")]
         data_gene[gb.accession] = [x for x in features if (x.type == "gene")]
 
@@ -309,9 +311,14 @@ def find_id(id):
 
     tax_file = taxidmap_file
     found = False
+    i = 0
     with open(tax_file, 'r') as inF:
         for line in inF:
             line = line.split()
+            # i+=1
+            # print i,line
+#             if id == "1246979":
+#                 print line[0]
             if str(id) == str(line[0]):
                 found = True
                 break
@@ -337,7 +344,7 @@ def missing_leafs():
         line = line.split("  ")
         lst = ast.literal_eval(line[1])
         for i in range(len(lst)):
-            if find_id(lst[i]) is True:
+            if find_id(lst[i]) == True:
                 all_deleted.append(lst[i])
     ndel.close()
     return lst
@@ -348,7 +355,7 @@ def remove_leaf_no_acc(t):
     #     not_deleted = open(outp_dir+"not_deleted.txt","w")
     #     deleted = open(outp_dir+"deleted.txt","w")
     for nd in t.traverse("postorder"):
-        if find_id(nd.name) is False and nd.is_leaf():
+        if find_id(nd.name) == False and nd.is_leaf():
 
             # deleted.write(str(nd.name)+" "+get_Nc(taxidmap_file,nd.name)+" "+str(nd.get_leaf_names())+"\n")
             nd.delete(prevent_nondicotomic=False)
@@ -365,22 +372,22 @@ def remove_leaf_no_acc(t):
 def convert_dict_PCG(dicti):
     d = {}
     for acc in dicti:
-        if acc not in d:
+        if not acc in d:
             d[acc] = {}
         for g in range(len(dicti[acc])):
-            # print dicti[acc][g].name
+                # print dicti[acc][g].name
             # print dict[acc][g].name
-            if dicti[acc][g].name not in d[acc]:
+            if not dicti[acc][g].name in d[acc]:
                 d[acc][dicti[acc][g].name] = {}
                 # anti_codon=str(dicti[acc][g].anticodon).replace('T','U')
             # d[acc][dicti[acc][g].name]['seq']=dicti[acc][g].sequence+anti_codon
-            if 'start' not in d[acc][dicti[acc][g].name]:
+            if not 'start' in d[acc][dicti[acc][g].name]:
                 d[acc][dicti[acc][g].name]['start'] = []
 
-            if 'stop' not in d[acc][dicti[acc][g].name]:
+            if not 'stop' in d[acc][dicti[acc][g].name]:
                 d[acc][dicti[acc][g].name]['stop'] = []
 
-            if 'score' not in d[acc][dicti[acc][g].name]:
+            if not 'score' in d[acc][dicti[acc][g].name]:
                 d[acc][dicti[acc][g].name]['score'] = []
 
             d[acc][dicti[acc][g].name]['start'].append(dicti[acc][g].start)
@@ -394,7 +401,7 @@ def convert_dict_PCG(dicti):
 def aff_seq(nd, data_gene):
 
     if nd.is_leaf():
-        if found_gene(nd.name, "nad5", data_gene) is True:
+        if found_gene(nd.name, "nad5", data_gene) == True:
             # if not nd.seq =='':
             fasta = nd.seq
             nd.seq = fasta
@@ -430,7 +437,7 @@ def which_gene(t, dat_gene):
             # print nd.name
             for chld in nd.get_children():
                 if chld.is_leaf():
-                    if found_gene(chld.name, "nad5", dat_gene) is True:
+                    if found_gene(chld.name, "nad5", dat_gene) == True:
                         i = 0
                         break
                     else:
@@ -458,7 +465,7 @@ def recursive_bifurcate(t, nd, dat_gene):
     ### tree bifurcation should be done by taking one sequence from each children, when childrens are subtrees, we take a random sequence from these sequences.
 
     check for internal nodes with more than 2 children, creates a fasta file with the sequences in the leafs of this internal node then it generates a Stockholm alignment using 'align_generate'.
-    'align_generate' creates an alignment in stockholm alignment which is passed to quicktree call to bifurcate this subtree and output the new subtree of this node in new hampshire format (NH)
+    'align_generate' creates an alignment in stockholm alignment which is passed to quicktree call to bifurcate this subtree and output the new subtree of this node in new hampshire format (NH) 
     @param[in] node in the tree
 
     """
@@ -474,7 +481,7 @@ def recursive_bifurcate(t, nd, dat_gene):
 
             if chld.is_leaf():
 
-                if found_gene(chld.name, "nad5", data_gene) is True:
+                if found_gene(chld.name, "nad5", data_gene) == True:
                     fasta += chld.seq
                 else:
                     # what should we do with the leaf with no nad5 ??
@@ -497,7 +504,8 @@ def recursive_bifurcate(t, nd, dat_gene):
 
     # print nd.name, fasta
     if not fasta == '' and not nd.is_leaf():
-        # print nd.name
+
+            # print nd.name
         fasta_file = open(
             work_dir + 'nad5_fasta_files/' + nd.name + '.fas', 'w')
         fasta_file.write(str(fasta))
@@ -506,8 +514,8 @@ def recursive_bifurcate(t, nd, dat_gene):
 
 #             if not os.path.isfile()
         align_generate(work_dir + 'nad5_fasta_files/' + nd.name + '.fas')
-        os.system("quicktree -upgma " + work_dir + 'stockholm_alignments/'
-                  + nd.name + '.sth > ' + work_dir + "Newick_trees/" + nd.name + ".nh")
+        os.system("quicktree -upgma " + work_dir + 'stockholm_alignments/' +
+                  nd.name + '.sth > ' + work_dir + "Newick_trees/" + nd.name + ".nh")
 
     for cld in nd.get_children():
         if not cld.is_leaf():
@@ -523,7 +531,7 @@ def dict_tree_files(NH_trees_dir):
     trees_dict = {}
     for tr in os.listdir(NH_trees_dir):
         fname, ext = os.path.splitext(tr)
-        if fname not in trees_dict:
+        if not fname in trees_dict:
 
             trees_dict[fname] = Tree(os.path.join(NH_trees_dir, fname + ".nh"))
 
@@ -566,7 +574,7 @@ def internal_node_check(some_tree):
     """
 
     for nd in some_tree.traverse():
-        if not nd.is_leaf() and find_id(nd.name) is True:
+        if not nd.is_leaf() and find_id(nd.name) == True:
             # print nd.name
             become_root = nd
             nd.add_child(name=nd.name)
@@ -640,6 +648,9 @@ def genes_sort_check(data_gene):
 
     # toignore = ['atp9', 'msh1', 'mttb', 'polB', 'heg']
 
+    genes = ["rrnS", "rrnL", "nad1", "nad2", "cox1", "cox2", "atp8",
+             "atp6", "cox3", "nad3", "nad4", "nad4l", "nad5", "nad6", "cob"]
+
     j = 0
     for acc in data_gene:
         j += 1
@@ -652,7 +663,7 @@ def genes_sort_check(data_gene):
         for g in data_gene[acc]:
 
             fseq = ""
-            ll = 0
+            l = 0
             if len(data_gene[acc][g]['start']) > 1:
                 # print g
                 for i in range(len(data_gene[acc][g]['start'])):
@@ -663,7 +674,7 @@ def genes_sort_check(data_gene):
                     # print g, start, end
                     try:
                         fseq += str(seq.subseq(start, end, strand))
-                    except Exception:
+                    except:
                         print("Bleeeeeeeeeeh !!!")
 
                         if len(seq) - start > end:
@@ -675,7 +686,7 @@ def genes_sort_check(data_gene):
                         # print "1"
 
                     #    fseq += str(seq.subseq( start,end , strand ))
-                    ll += 1
+                    l += 1
             elif len(data_gene[acc][g]['start']) == 1:
 
                 start = data_gene[acc][g]['start'][0]
@@ -685,7 +696,7 @@ def genes_sort_check(data_gene):
 
                 try:
                     fseq = str(seq.subseq(start, end, strand))
-                except Exception:
+                except:
                     print("Bleeeeeeeeeeh !!!")
 
                     if len(seq) - start > end:
@@ -694,10 +705,10 @@ def genes_sort_check(data_gene):
                         fseq = str(seq.subseq(0, end, strand))
                 # else:
                 #    fseq = str(seq.subseq( start,end , strand ))
-                ll += 1
+                l += 1
 
             outfile.write(
-                acc + "    " + g + "    " + str(len(fseq) - ll) + "\n")
+                acc + "    " + g + "    " + str(len(fseq) - l) + "\n")
     outfile.close()
 
     print("number of tested species " + str(j))
@@ -736,6 +747,7 @@ def get_sequence_PCgenes(node_id, gene, fasta_files_dir, data):
 
 def intialize_non_leaves(t):
     global taxidmap_file
+    tax_file = taxidmap_file
 
     for n in t.traverse(strategy='postorder'):
         if not n.is_leaf():
@@ -750,7 +762,7 @@ def initialize_leaves(t, data_array):
     for n in t.traverse(strategy='postorder'):
         # and n.is_leaf(): might be important
         if get_Nc(tax_file, n.name) in data_array:
-            if found_gene(n.name, "nad5", data_array) is True:
+            if found_gene(n.name, "nad5", data_array) == True:
                 n.add_feature('seq', "> " + n.name + "\n" + get_sequence_PCgenes(
                     n.name, "nad5", fasta_files_dir, data_array) + "\n")
             else:
@@ -818,8 +830,8 @@ if __name__ == '__main__':
     for nd in tr:
         # ff.write(str(nd.name)+"\n")
         i += 1
-    print("after removing the non-mitochondrial leafs, the tree has "
-          + str(i) + " leafs")
+    print("after removing the non-mitochondrial leafs, the tree has " +
+          str(i) + " leafs")
     # ff.close()
 
 
