@@ -3,22 +3,26 @@
 '''
 @author: M. Bernt
 
-remove a certain gene from the sequence and
+This is a confidential release. Do not redistribute without 
+permission of the author (bernt@informatik.uni-leipzig.de).
+
+remove a certain gene from the sequence and 
 '''
+from __future__ import print_function
 from optparse import OptionParser
 from sys import exit, stderr, stdout
 
 from gb import gbfromfile
 
 usage = """%prog [options] fasta files/fasta directory"
-    predicts proteins with blastx, and writes the aminoacid sequences
+    predicts proteins with blastx, and writes the aminoacid sequences  
 
-genetic code:
+genetic code: 
 - if genbank file with same name is found the code specified there is assumed
 - otherwise the genetic code specified with --code is assumed
-circularity is assumed to circular per default:
+circularity is assumed to circular per default: 
 - if genbank file with same name is found the circularity is taken from there
-- otherwise default circularity is assumed (can be set to linear with --linear)
+- otherwise default circularity is assumed (can be set to linear with --linear)      
 """
 parser = OptionParser(usage)
 parser.add_option("-n", "--aname", action="append", type="string",
